@@ -1,19 +1,7 @@
-/* This file is part of StepCore library.
-   Copyright (C) 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
+/*
+    SPDX-FileCopyrightText: 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
 
-   StepCore library is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
-
-   StepCore library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with StepCore; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "eulersolver.h"
@@ -44,9 +32,9 @@ void GenericEulerSolver::fini()
 int GenericEulerSolver::doCalcFn(double* t, const VectorXd* y,
                     const VectorXd* yvar, VectorXd* f, VectorXd* fvar)
 {
-    int ret = _function(*t, y->data(), yvar?yvar->data():0,
+    int ret = _function(*t, y->data(), yvar?yvar->data():nullptr,
                             f ? f->data() : _ydiff.data(),
-                            fvar?fvar->data():0, _params);
+                            fvar?fvar->data():nullptr, _params);
     //if(f != NULL) std::memcpy(f, _ydiff, _dimension*sizeof(*f));
     return ret;
 }
@@ -59,8 +47,8 @@ int GenericEulerSolver::doStep(double t, double stepSize, VectorXd* y, VectorXd*
     //int ret = _function(t, y, _ydiff, _params);
     //if(ret != OK) return ret;
 
-    VectorXd* ytempvar = yvar ? &_ytempvar : 0;
-    VectorXd* ydiffvar = yvar ? &_ydiffvar : 0;
+    VectorXd* ytempvar = yvar ? &_ytempvar : nullptr;
+    VectorXd* ydiffvar = yvar ? &_ydiffvar : nullptr;
 
     // Error estimation: integration with timestep = stepSize
     _yerr = - *y - stepSize*_ydiff;
@@ -71,8 +59,8 @@ int GenericEulerSolver::doStep(double t, double stepSize, VectorXd* y, VectorXd*
         *ytempvar = (yvar->array().sqrt().matrix()+(stepSize/2)*(*ydiffvar)).array().square().matrix();
     }
 
-    int ret = _function(t + stepSize/2, _ytemp.data(), ytempvar?ytempvar->data():0,
-                        _ydiff.data(), ydiffvar?ydiffvar->data():0, _params);
+    int ret = _function(t + stepSize/2, _ytemp.data(), ytempvar?ytempvar->data():nullptr,
+                        _ydiff.data(), ydiffvar?ydiffvar->data():nullptr, _params);
     if(ret != OK) return ret;
 
     for(int i=0; i<_dimension; ++i) {
@@ -93,8 +81,8 @@ int GenericEulerSolver::doStep(double t, double stepSize, VectorXd* y, VectorXd*
     if(_localErrorRatio > 1.1) return ToleranceError;
 
     // XXX
-    ret = _function(t + stepSize, _ytemp.data(), ytempvar?ytempvar->data():0,
-                    _ydiff.data(), ydiffvar?ydiffvar->data():0, _params);
+    ret = _function(t + stepSize, _ytemp.data(), ytempvar?ytempvar->data():nullptr,
+                    _ydiff.data(), ydiffvar?ydiffvar->data():nullptr, _params);
     if(ret != OK) return ret;
 
     *y = _ytemp;
@@ -127,9 +115,9 @@ int GenericEulerSolver::doEvolve(double* t, double t1, VectorXd* y, VectorXd* yv
     const double S = 0.9;
     int result;
 
-    VectorXd* ydiffvar = yvar ? &_ydiffvar : 0;
+    VectorXd* ydiffvar = yvar ? &_ydiffvar : nullptr;
 
-    result = _function(*t, y->data(), yvar?yvar->data():0, _ydiff.data(), ydiffvar?ydiffvar->data():0, _params);
+    result = _function(*t, y->data(), yvar?yvar->data():nullptr, _ydiff.data(), ydiffvar?ydiffvar->data():nullptr, _params);
     if(result != OK) return result;
 
     while(*t < t1) {
@@ -154,8 +142,8 @@ int GenericEulerSolver::doEvolve(double* t, double t1, VectorXd* y, VectorXd* yv
                 if(newStepSize < t1 - t11) _stepSize = newStepSize;
             }
             if(result != OK) {
-                result = _function(*t, y->data(), yvar?yvar->data():0, _ydiff.data(),
-                                   ydiffvar?ydiffvar->data():0, _params);
+                result = _function(*t, y->data(), yvar?yvar->data():nullptr, _ydiff.data(),
+                                   ydiffvar?ydiffvar->data():nullptr, _params);
                 if(result != OK) return result;
                 continue;
             }
