@@ -1,19 +1,7 @@
-/* This file is part of StepCore library.
-   Copyright (C) 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
+/*
+    SPDX-FileCopyrightText: 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
 
-   StepCore library is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
-
-   StepCore library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with StepCore; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 /** \file eulersolver.h
@@ -57,8 +45,8 @@ public:
 
     void setDimension(int dimension) override { fini(); _dimension = dimension; init(); }
 
-    int doCalcFn(double* t, const VectorXd* y, const VectorXd* yvar = 0,
-                        VectorXd* f = 0, VectorXd* fvar = 0) override;
+    int doCalcFn(double* t, const VectorXd* y, const VectorXd* yvar = nullptr,
+                        VectorXd* f = nullptr, VectorXd* fvar = nullptr) override;
     int doEvolve(double* t, double t1, VectorXd* y, VectorXd* yvar) override;
 
 protected:
