@@ -1,19 +1,7 @@
-/* This file is part of StepCore library.
-   Copyright (C) 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
+/*
+    SPDX-FileCopyrightText: 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
 
-   StepCore library is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
-
-   StepCore library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with StepCore; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 /** \file particle.h
@@ -41,7 +29,7 @@ class ParticleErrors: public ObjectErrors
 
 public:
     /** Constructs ParticleErrors */
-    explicit ParticleErrors(Item* owner = 0)
+    explicit ParticleErrors(Item* owner = nullptr)
         : ObjectErrors(owner), _positionVariance(0,0), _velocityVariance(0,0),
           _forceVariance(0,0), _massVariance(0) {}
 
@@ -182,7 +170,7 @@ class ChargedParticleErrors: public ParticleErrors
 
 public:
     /** Constructs ChargedParticleErrors */
-    explicit ChargedParticleErrors(Item* owner = 0)
+    explicit ChargedParticleErrors(Item* owner = nullptr)
         : ParticleErrors(owner), _chargeVariance(0) {}
 
     /** Get owner as ChargedParticle */
